@@ -10,7 +10,7 @@ use ExtUtils::CBuilder::Base;
 use IO::File;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.26_05';
+$VERSION = '0.27_04';
 @ISA = qw(ExtUtils::CBuilder::Base);
 
 =begin comment
@@ -86,6 +86,9 @@ sub compile {
 
   die "Missing 'source' argument to compile()" unless defined $args{source};
 
+  $args{include_dirs} = [ $args{include_dirs} ] 
+    if exists($args{include_dirs}) && ref($args{include_dirs}) ne "ARRAY";
+
   my ($basename, $srcdir) =
     ( File::Basename::fileparse($args{source}, '\.[^.]+$') )[0,1];
 
@@ -98,7 +101,7 @@ sub compile {
     builddir    => $srcdir,
     basename    => $basename,
     source      => $args{source},
-    output      => File::Spec->catfile($srcdir, $basename) . $cf->{obj_ext},
+    output      => $args{object_file} || File::Spec->catfile($srcdir, $basename) . $cf->{obj_ext},
     cc          => $cf->{cc},
     cflags      => [
                      $self->split_like_shell($cf->{ccflags}),
